{% extends "base.html" %}

{% block title %}Page Not found{% endblock %}

{% block page_title %}Page Not found{% endblock page_title %}

{% block content %}
<p>This is not the page you were looking for.</p>
{% endblock content %}